window.Gleam.initSearch([{"doc":"gsv","title":"gsv","content":"# gsv\n\n[![Package Version](https://img.shields.io/hexpm/v/csv)](https://hex.pm/packages/csv)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/csv/)\n\nThis is a simple csv parser and writer for gleam. It will get more performant in the future,\nbut if you&#39;re looking for high performance now, I&#39;d recommend doing ffi to an existing parser\nin your target runtime.\n\nWe are using the grammar from [rfc 4180](https://datatracker.ietf.org/doc/html/rfc4180#section-2)\n\n#### Example\n\n```gleam\nimport gsv.{Unix, Windows}\n\npub fn main() {\n  let csv_str = &quot;Hello, World\\nGoodbye, Mars&quot;\n\n  // Parse a CSV string to a List(List(String))\n  let assert Ok(records) = gsv.to_lists(csv_str)\n\n  // Write a List(List(String)) to a CSV string\n  let csv_str = records\n  |&gt; gsv.from_lists(separator: &quot;,&quot;, line_ending: Windows)\n}\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add csv\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/csv&gt;.\n","url":"index.html"},{"doc":"gsv","title":"LineEnding","content":"pub type LineEnding {\n  Windows\n  Unix\n}\n Option for using &quot;\\n = LF = Unix&quot; or &quot;\\r\\n = CRLF = Windows&quot;\n line endings. Use with the `from_lists` function when \n writing to a csv string.\nWindows\n\n\nUnix\n\n\nSynonyms:\ngsv.LineEnding\ngsv LineEnding","url":"gsv.html#LineEnding"},{"doc":"gsv","title":"from_lists","content":"pub fn from_lists(\n  input: List(List(String)),\n  separator separator: String,\n  line_ending line_ending: LineEnding,\n) -&gt; String\n Takes a list of lists of strings and writes it to a csv string.\n Will automatically escape strings that contain double quotes or\n line endings with double quotes (in csv, double quotes get escaped by doing\n a double doublequote)\n The string `he&quot;llo\\n` becomes `&quot;he&quot;&quot;llo\\n&quot;`\nSynonyms:\ngsv.from_lists\ngsv from_lists","url":"gsv.html#from_lists"},{"doc":"gsv","title":"to_lists","content":"pub fn to_lists(input: String) -&gt; Result(List(List(String)), Nil)\n Parses a csv string to a list of lists of strings.\n Automatically handles Windows and Unix line endings.\nSynonyms:\ngsv.to_lists\ngsv to_lists","url":"gsv.html#to_lists"},{"doc":"gsv","title":"to_lists_or_error","content":"pub fn to_lists_or_error(\n  input: String,\n) -&gt; Result(List(List(String)), String)\n Parses a csv string to a list of lists of strings.\n Automatically handles Windows and Unix line endings.\n Returns a string error msg if the string is not valid csv.\nSynonyms:\ngsv.to_lists_or_error\ngsv to_lists_or_error","url":"gsv.html#to_lists_or_error"},{"doc":"gsv","title":"to_lists_or_panic","content":"pub fn to_lists_or_panic(input: String) -&gt; List(List(String))\n Parses a csv string to a list of lists of strings.\n Automatically handles Windows and Unix line endings.\n Panics with an error msg if the string is not valid csv.\nSynonyms:\ngsv.to_lists_or_panic\ngsv to_lists_or_panic","url":"gsv.html#to_lists_or_panic"},{"doc":"gsv","title":"gsv","content":"","url":"gsv.html"}]);